@@ -113,6 +113,14 @@ class Presenter:
         self.ensemble = ensemble
         self.metadata = defaultdict(list)
 
+    @property
+    def dwell(self) -> float:
+        return float(next(reversed(self.metadata["dwell"]), "0.3"))
+
+    @property
+    def pause(self) -> float:
+        return float(next(reversed(self.metadata["pause"]), "1.0"))
+
     @property
     def pending(self) -> int:
         return len([
